LoadCommandData

Struct LoadCommandData 

pub struct LoadCommandData<'data, E: Endian> { /* private fields */ }
The data for a macho::LoadCommand.

Implementations

Source

impl<'data, E: Endian> LoadCommandData<'data, E>

pub fn cmd(&self) -> u32

Return the cmd field of the macho::LoadCommand.

This is one of the LC_ constants.

pub fn cmdsize(&self) -> u32

Return the cmdsize field of the macho::LoadCommand.

pub fn data<T: Pod>(&self) -> Result<&'data T>

Parse the data as the given type.

pub fn raw_data(&self) -> &'data [u8]

Raw bytes of this macho::LoadCommand structure.

pub fn string(&self, endian: E, s: LcStr<E>) -> Result<&'data [u8]>

Parse a load command string value.

Strings used by load commands are specified by offsets that are relative to the load command header.

pub fn variant(&self) -> Result<LoadCommandVariant<'data, E>>

Parse the command data according to the cmd field.

pub fn segment_32( self, ) -> Result<Option<(&'data SegmentCommand32<E>, &'data [u8])>>

Try to parse this command as a macho::SegmentCommand32.

Returns the segment command and the data containing the sections.

pub fn symtab(self) -> Result<Option<&'data SymtabCommand<E>>>

Try to parse this command as a macho::SymtabCommand.

pub fn dysymtab(self) -> Result<Option<&'data DysymtabCommand<E>>>

Try to parse this command as a macho::DysymtabCommand.

pub fn dylib(self) -> Result<Option<&'data DylibCommand<E>>>

Try to parse this command as a macho::DylibCommand.

See also Self::dylib_use_flags to read the optional flags field.

pub fn dylib_use_flags( self, endian: E, dylib: &DylibCommand<E>, ) -> Result<Option<u32>>

Parse the optional flags field for a dylib load command.

macho::DylibCommand traditionally uses the load command type to distinguish between dylib kinds. macho::DylibUseCommand replaces this by encoding the kinds in a bitfield appended after the standard DylibCommand fields. Its presence is signalled using sentinel values in some DylibCommand fields.

Returns None if the sentinels are absent. If Some is returned, the value of macho::Dylib::timestamp should be ignored.

pub fn uuid(self) -> Result<Option<&'data UuidCommand<E>>>

Try to parse this command as a macho::UuidCommand.

pub fn segment_64( self, ) -> Result<Option<(&'data SegmentCommand64<E>, &'data [u8])>>

Try to parse this command as a macho::SegmentCommand64.

pub fn dyld_info(self) -> Result<Option<&'data DyldInfoCommand<E>>>

Try to parse this command as a macho::DyldInfoCommand.

pub fn entry_point(self) -> Result<Option<&'data EntryPointCommand<E>>>

Try to parse this command as an macho::EntryPointCommand.

pub fn unix_thread( self, ) -> Result<Option<(&'data ThreadCommand<E>, &'data [u8])>>

Try to parse this command as an LC_UNIXTHREAD macho::ThreadCommand.

Returns the thread command and the thread state data that follows it.

pub fn build_version(self) -> Result<Option<&'data BuildVersionCommand<E>>>

Try to parse this command as a macho::BuildVersionCommand.